@@ -102,7 +102,7 @@ def imshow (Z, vmin=None, vmax=None, cmap=CM_Hot, show_cmap=False):
             data += "\x1b[0m  "
             data += "\x1b[48;5;%dm  " % (16 + (1-i/float(Z.shape[0]))*239)
             data += "\x1b[0m %+.2f" % u
-        data += "\n"
+        data += "\x1b[0m\n"
     print init+data[:-1]+'\x1b[0m'
 
 
